@@ -78,6 +78,7 @@ class Calculation(InputTemplate):
         self._pair_style = None
         self._pair_coeff = None
         self._potential_file = None
+        self._fix_potential_path = True
         self._reference_phase = None
         self._lattice_constant = 0
         self._repeat = [1, 1, 1]
@@ -87,6 +88,9 @@ class Calculation(InputTemplate):
         self._n_sweep_steps = 50000
         self._n_print_steps = 0
         self._n_iterations = 1
+
+        #add second level options; for example spring constants
+        self._spring_constants = None
         
         self.md = InputTemplate()
         self.md.timestep = 0.001
@@ -326,7 +330,8 @@ class Calculation(InputTemplate):
     @pair_coeff.setter
     def pair_coeff(self, val):
         val = self.check_and_convert_to_list(val)
-        val = self.fix_paths(val)
+        if self._fix_potential_path:
+            val = self.fix_paths(val)
         self._pair_coeff = val
 
     @property
@@ -416,25 +421,40 @@ class Calculation(InputTemplate):
     @n_iterations.setter
     def n_iterations(self, val):
         self._n_iterations = val
+
+    @property
+    def spring_constants(self):
+        return self._spring_constants
+
+    @spring_constants.setter
+    def spring_constants(self, val):
+        val = self.check_and_convert_to_list(val)
+        self._spring_constants = val
     
-    def check_and_convert_to_list(self, data):
+    def check_and_convert_to_list(self, data, check_none=False):
         """
         Check if the given item is a list, if not convert to a single item list
         """
         if not isinstance(data, list):
-            return [data]
-        else:
-            return data
+            data = [data]
+
+        if check_none:
+            data = [None if x=="None" else x for x in data]
+
+        return data
     
     @staticmethod
-    def convert_to_list(data):
+    def convert_to_list(data, check_none=False):
         """
         Check if the given item is a list, if not convert to a single item list
         """
         if not isinstance(data, list):
-            return [data]
-        else:
-            return data
+            data = [data]
+
+        if check_none:
+            data = [None if x=="None" else x for x in data]
+
+        return data
 
     def fix_paths(self, potlist): 
         """
@@ -474,11 +494,14 @@ class Calculation(InputTemplate):
             l = 'tm'
         else:
             ts = int(self._temperature)
-            ps = int(self._pressure)
+            if self._pressure is None:
+                ps = "None"
+            else:
+                ps = "%d"%(int(self._pressure))
             l = self.lattice
             l = l.split('/')
             l = l[-1]
-        identistring = "-".join([prefix, l, str(ts), str(ps)])
+        identistring = "-".join([prefix, l, str(ts), ps])
         return identistring
 
     def create_folders(self, prefix=None):
@@ -566,15 +589,15 @@ def read_inputfile(file):
         if mode == "melting_temperature":
             calc = Calculation.generate(indata)
             calc.add_from_dict(ci, keys=["mode", "pair_style", "pair_coeff", "repeat", "n_equilibration_steps",
-                                "n_switching_steps", "n_print_steps", "n_iterations"])
-            calc.pressure = Calculation.convert_to_list(ci["pressure"]) if "pressure" in ci.keys() else 0
+                                "n_switching_steps", "n_print_steps", "n_iterations", "spring_constants"])
+            calc.pressure = Calculation.convert_to_list(ci["pressure"], check_none=True) if "pressure" in ci.keys() else 0
             calc.temperature = Calculation.convert_to_list(ci["temperature"]) if "temperature" in ci.keys() else None
             calc.lattice = Calculation.convert_to_list(ci["lattice"]) if "lattice" in ci.keys() else None
             calc.reference_phase = Calculation.convert_to_list(ci["reference_phase"]) if "reference_phase" in ci.keys() else None
             calc.lattice_constant = Calculation.convert_to_list(ci["lattice_constant"]) if "lattice_constant" in ci.keys() else 0 
             calculations.append(calc)
         else:
-            pressure = Calculation.convert_to_list(ci["pressure"]) if "pressure" in ci.keys() else []
+            pressure = Calculation.convert_to_list(ci["pressure"], check_none=True) if "pressure" in ci.keys() else []
             temperature = Calculation.convert_to_list(ci["temperature"]) if "temperature" in ci.keys() else []
             lattice = Calculation.convert_to_list(ci["lattice"])
             reference_phase = Calculation.convert_to_list(ci["reference_phase"])
@@ -601,7 +624,7 @@ def read_inputfile(file):
             for combo in combos:
                 calc = Calculation.generate(indata)
                 calc.add_from_dict(ci, keys=["mode", "pair_style", "pair_coeff", "repeat", "n_equilibration_steps",
-                                "n_switching_steps", "n_print_steps", "n_iterations", "potential_file"])
+                                "n_switching_steps", "n_print_steps", "n_iterations", "potential_file", "spring_constants"])
                 calc.lattice = combo[0]["lattice"]
                 calc.lattice_constant = combo[0]["lattice_constant"]
                 calc.reference_phase = combo[0]["reference_phase"]
